@@ -10,25 +10,25 @@ SPVM::Double - Double Utility
 
 =head2 MIN_VALUE
 
-B<double MIN_VALUE()>
+B<sub MIN_VALUE : double ()>
 
 A constant holding the minimum value a double can have, C<-128>.
 
 =head2 MAX_VALUE
 
-B<double MAX_VALUE()>
+B<sub MAX_VALUE : double ()>
 
 A constant holding the maximum value a double can have, C<127>.
 
 =head2 SIZE
 
-B<int SIZE>
+B<sub SIZE : int ()>
 
 The number of bits used to represent a double value in two's complement binary form.
 
 =head2 BYTES
 
-B<int BYTES()>
+B<sub BYTES : int ()>
 
 The number of doubles used to represent a double value in two's complement binary form.
 
