@@ -20,16 +20,16 @@ int32_t SPVM_FIELD_get_byte_size(SPVM_COMPILER* compiler, SPVM_FIELD* field) {
   SPVM_TYPE* field_type = field->op_type->uv.type;
   
   int32_t byte_size;
-  if (field_type->id == SPVM_TYPE_C_ID_BYTE) {
+  if (field_type->code == SPVM_TYPE_C_CODE_BYTE) {
     byte_size = sizeof(int8_t);
   }
-  else if (field_type->id == SPVM_TYPE_C_ID_SHORT) {
+  else if (field_type->code == SPVM_TYPE_C_CODE_SHORT) {
     byte_size = sizeof(int16_t);
   }
-  else if (field_type->id == SPVM_TYPE_C_ID_INT || field_type->id == SPVM_TYPE_C_ID_FLOAT) {
+  else if (field_type->code == SPVM_TYPE_C_CODE_INT || field_type->code == SPVM_TYPE_C_CODE_FLOAT) {
     byte_size = sizeof(int32_t);
   }
-  else if (field_type->id == SPVM_TYPE_C_ID_LONG || field_type->id == SPVM_TYPE_C_ID_DOUBLE) {
+  else if (field_type->code == SPVM_TYPE_C_CODE_LONG || field_type->code == SPVM_TYPE_C_CODE_DOUBLE) {
     byte_size = sizeof(int64_t);
   }
   else {
