@@ -98,66 +98,44 @@
 
 const char* const SPVM_OPCODE_C_CODE_NAMES[] = {
   "NOP",
-  "ADD_BYTE",
-  "ADD_SHORT",
   "ADD_INT",
   "ADD_LONG",
   "ADD_FLOAT",
   "ADD_DOUBLE",
-  "SUBTRACT_BYTE",
-  "SUBTRACT_SHORT",
   "SUBTRACT_INT",
   "SUBTRACT_LONG",
   "SUBTRACT_FLOAT",
   "SUBTRACT_DOUBLE",
-  "MULTIPLY_BYTE",
-  "MULTIPLY_SHORT",
   "MULTIPLY_INT",
   "MULTIPLY_LONG",
   "MULTIPLY_FLOAT",
   "MULTIPLY_DOUBLE",
-  "DIVIDE_BYTE",
-  "DIVIDE_SHORT",
   "DIVIDE_INT",
   "DIVIDE_LONG",
   "DIVIDE_FLOAT",
   "DIVIDE_DOUBLE",
-  "REMAINDER_BYTE",
-  "REMAINDER_SHORT",
   "REMAINDER_INT",
   "REMAINDER_LONG",
   "REMAINDER_FLOAT",
   "REMAINDER_DOUBLE",
-  "LEFT_SHIFT_BYTE",
-  "LEFT_SHIFT_SHORT",
   "LEFT_SHIFT_INT",
   "LEFT_SHIFT_LONG",
-  "RIGHT_SHIFT_BYTE",
-  "RIGHT_SHIFT_SHORT",
   "RIGHT_SHIFT_INT",
   "RIGHT_SHIFT_LONG",
-  "RIGHT_SHIFT_UNSIGNED_BYTE",
-  "RIGHT_SHIFT_UNSIGNED_SHORT",
   "RIGHT_SHIFT_UNSIGNED_INT",
   "RIGHT_SHIFT_UNSIGNED_LONG",
-  "BIT_AND_BYTE",
-  "BIT_AND_SHORT",
   "BIT_AND_INT",
   "BIT_AND_LONG",
-  "BIT_OR_BYTE",
-  "BIT_OR_SHORT",
   "BIT_OR_INT",
   "BIT_OR_LONG",
-  "BIT_XOR_BYTE",
-  "BIT_XOR_SHORT",
   "BIT_XOR_INT",
   "BIT_XOR_LONG",
-  "COMPLEMENT_BYTE",
-  "COMPLEMENT_SHORT",
   "COMPLEMENT_INT",
   "COMPLEMENT_LONG",
-  "NEGATE_BYTE",
-  "NEGATE_SHORT",
+  "PLUS_INT",
+  "PLUS_LONG",
+  "PLUS_FLOAT",
+  "PLUS_DOUBLE",
   "NEGATE_INT",
   "NEGATE_LONG",
   "NEGATE_FLOAT",
@@ -198,41 +176,29 @@ const char* const SPVM_OPCODE_C_CODE_NAMES[] = {
   "CONVERT_LONG_TO_LONG",
   "CONVERT_FLOAT_TO_FLOAT",
   "CONVERT_DOUBLE_TO_DOUBLE",
-  "GT_BYTE",
-  "GT_SHORT",
   "GT_INT",
   "GT_LONG",
   "GT_FLOAT",
   "GT_DOUBLE",
-  "GE_BYTE",
-  "GE_SHORT",
   "GE_INT",
   "GE_LONG",
   "GE_FLOAT",
   "GE_DOUBLE",
-  "LT_BYTE",
-  "LT_SHORT",
   "LT_INT",
   "LT_LONG",
   "LT_FLOAT",
   "LT_DOUBLE",
-  "LE_BYTE",
-  "LE_SHORT",
   "LE_INT",
   "LE_LONG",
   "LE_FLOAT",
   "LE_DOUBLE",
   "IS_UNDEF",
   "IS_NOT_UNDEF",
-  "EQ_BYTE",
-  "EQ_SHORT",
   "EQ_INT",
   "EQ_LONG",
   "EQ_FLOAT",
   "EQ_DOUBLE",
   "EQ_OBJECT",
-  "NE_BYTE",
-  "NE_SHORT",
   "NE_INT",
   "NE_LONG",
   "NE_FLOAT",
@@ -242,15 +208,14 @@ const char* const SPVM_OPCODE_C_CODE_NAMES[] = {
   "INC_SHORT",
   "INC_INT",
   "INC_LONG",
-  "BOOL_BYTE",
-  "BOOL_SHORT",
+  "INC_FLOAT",
+  "INC_DOUBLE",
   "BOOL_INT",
   "BOOL_LONG",
   "BOOL_FLOAT",
   "BOOL_DOUBLE",
   "BOOL_OBJECT",
   "LOAD_UNDEF",
-  "MOVE",
   "NEW_OBJECT",
   "NEW_STRING",
   "NEW_OBJECT_ARRAY",
